/*
**  MixerController.m
**
**  Copyright (c) 2002
**
**  Author: Yen-Ju Chen <yjchenx@yahoo.com.tw>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#import "MixerController.h"
#import "Mixer.h"
#import "ChannelView.h"

@implementation MixerController

- (void) channel: (int) number changeLeft: (float) left
                                    right: (float) right
{
  float volume, balance;
  lr_to_vb(left, right, &volume, &balance);
  [mixer setCurrentChannel: number];
  [mixer setCurrentVolume: volume];
  [mixer setCurrentBalance: balance];
}

- (void) channel: (int) number
         didChangeMute: (int) state
{
  [mixer setCurrentChannel: number];
  [mixer setCurrentMute: state];
}

- (void) channel: (int) number
         didChangeRecord: (int) state
{
  [mixer setCurrentChannel: number];
  [mixer setCurrentRecord: state];
}

- (NSWindow *) window
{
  return window;
}

- (void) applicationDidFinishLaunching: (NSNotification *) not
{
  [window setDelegate: self];
  [window makeKeyAndOrderFront: self];
}

- (void) applicationWillFinishLaunching: (NSNotification *) not
{
  int i, y = 50;
  float left, right;

  window = [[NSWindow alloc] initWithContentRect: NSMakeRect(100,100,y,200)
                                       styleMask: (NSTitledWindowMask | 
                                                 NSClosableWindowMask | 
                                           NSMiniaturizableWindowMask)
                                         backing: NSBackingStoreRetained
                                           defer: NO];

  // Generate enough channel view
  for(i = 0; i < numberOfChannel; i++) {
    y = 1 + channelViewWidth * i;
    [mixer setCurrentChannel: i];
    channelView = [[ChannelView alloc] initWithFrame: NSMakeRect(y,1,
                                                  channelViewWidth,
                                                  channelViewHeight)];
    [channelView setName: [[mixer currentName] capitalizedString]];
    [channelView setNumber: i];
    [channelView setDelegate: self];
    vb_to_lr([mixer currentVolume], [mixer currentBalance], &left, &right);
    [channelView setLeftChannel: left];
    [channelView setRightChannel: right];
    [channelView setMute: [mixer isCurrentMuted]];

    if ([mixer currentCanRecord])
      [channelView setRecord: [mixer isCurrentRecord]];
    else
      [channelView setRecord: -1]; /* Take off recordButton */

    [[window contentView] addSubview: channelView];
    RELEASE(channelView);
  }
  [window setContentSize: NSMakeSize(y+channelViewWidth, channelViewHeight)];
  [window setTitle: @"Volumn Controller"];
}

// Terminate the application when window close
- (BOOL) applicationShouldTerminateAfterLastWindowClosed: (NSApplication *)aApp
{
  return YES;
}

- (id) init
{
  self = [super init];

// Init mixer
  mixer = [[Mixer alloc] initWithDevice: @"/dev/mixer"];
  [mixer setCurrentBalance: 0.0];
  [mixer setCurrentChannel: 0];

// Get number of channels
  numberOfChannel = [mixer totalChannels];

  return self;
}

- (void) dealloc
{
  RELEASE(mixer);
  [super dealloc];
}

@end
